summaryrefslogtreecommitdiffstats
path: root/libkdepim/ksubscription.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/ksubscription.h')
-rw-r--r--libkdepim/ksubscription.h76
1 files changed, 38 insertions, 38 deletions
diff --git a/libkdepim/ksubscription.h b/libkdepim/ksubscription.h
index 55ed5bd2..f72455b3 100644
--- a/libkdepim/ksubscription.h
+++ b/libkdepim/ksubscription.h
@@ -25,8 +25,8 @@
#ifndef __KSUBSCRIPTION
#define __KSUBSCRIPTION
-#include <qlistview.h>
-#include <qcheckbox.h>
+#include <tqlistview.h>
+#include <tqcheckbox.h>
#include <kdialogbase.h>
#include <kdepimmacros.h>
@@ -52,14 +52,14 @@ class KDE_EXPORT KGroupInfo
moderated
};
- KGroupInfo( const QString &name, const QString &description = QString::null,
+ KGroupInfo( const TQString &name, const TQString &description = TQString::null,
bool newGroup = false, bool subscribed = false,
- Status status = unknown, QString path = QString::null );
+ Status status = unknown, TQString path = TQString::null );
- QString name, description;
+ TQString name, description;
bool newGroup, subscribed;
Status status;
- QString path;
+ TQString path;
bool operator== (const KGroupInfo &gi2);
bool operator< (const KGroupInfo &gi2);
@@ -72,9 +72,9 @@ class KDE_EXPORT KGroupInfo
class KDE_EXPORT GroupItem : public QCheckListItem
{
public:
- GroupItem( QListView *v, const KGroupInfo &gi, KSubscription* browser,
+ GroupItem( TQListView *v, const KGroupInfo &gi, KSubscription* browser,
bool isCheckItem = false );
- GroupItem( QListViewItem *i, const KGroupInfo &gi, KSubscription* browser,
+ GroupItem( TQListViewItem *i, const KGroupInfo &gi, KSubscription* browser,
bool isCheckItem = false );
/**
@@ -86,8 +86,8 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Get/Set the original parent
*/
- QListViewItem* originalParent() { return mOriginalParent; }
- void setOriginalParent( QListViewItem* parent ) { mOriginalParent = parent; }
+ TQListViewItem* originalParent() { return mOriginalParent; }
+ void setOriginalParent( TQListViewItem* parent ) { mOriginalParent = parent; }
/**
* Get/Set the last open state
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
* Calls QListViewItem or QCheckListItem
*/
- virtual void paintCell( QPainter * p, const QColorGroup & cg,
+ virtual void paintCell( TQPainter * p, const TQColorGroup & cg,
int column, int width, int align );
/**
* Reimplemented
* Calls QListViewItem or QCheckListItem
*/
- virtual void paintFocus( QPainter *, const QColorGroup & cg,
- const QRect & r );
+ virtual void paintFocus( TQPainter *, const TQColorGroup & cg,
+ const TQRect & r );
/**
* Reimplemented
* Calls QListViewItem or QCheckListItem
*/
- virtual int width( const QFontMetrics&, const QListView*, int column) const;
+ virtual int width( const TQFontMetrics&, const TQListView*, int column) const;
/**
* Reimplemented
* Calls QListViewItem or QCheckListItem
*/
virtual void setup();
@@ -162,7 +162,7 @@ class KDE_EXPORT GroupItem : public QCheckListItem
protected:
KGroupInfo mInfo;
KSubscription* mBrowser;
- QListViewItem* mOriginalParent;
+ TQListViewItem* mOriginalParent;
// remember last open state
bool mLastOpenState;
// is this a checkable item
@@ -198,8 +198,8 @@ class KDE_EXPORT KSubscription : public KDialogBase
Right
};
- KSubscription( QWidget *parent, const QString &caption, KAccount* acct,
- int buttons = 0, const QString &user1 = QString::null,
+ KSubscription( TQWidget *parent, const TQString &caption, KAccount* acct,
+ int buttons = 0, const TQString &user1 = TQString::null,
bool descriptionColumn = true );
~KSubscription();
@@ -213,7 +213,7 @@ class KDE_EXPORT KSubscription : public KDialogBase
/**
* Access to the treewidget that holds the GroupItems
*/
- QListView* folderTree() { return groupView; }
+ TQListView* folderTree() { return groupView; }
/**
* Access to the searchfield
@@ -228,18 +228,18 @@ class KDE_EXPORT KSubscription : public KDialogBase
/**
* Removes the item from the listview
*/
- void removeListItem( QListView *view, const KGroupInfo &gi );
+ void removeListItem( TQListView *view, const KGroupInfo &gi );
/**
* Gets the item from the listview
* Returns 0 if the item can't be found
*/
- QListViewItem* getListItem( QListView *view, const KGroupInfo &gi );
+ TQListViewItem* getListItem( TQListView *view, const KGroupInfo &gi );
/**
* Is the item in the given listview
*/
- bool itemInListView( QListView *view, const KGroupInfo &gi );
+ bool itemInListView( TQListView *view, const KGroupInfo &gi );
/**
* Makes all changes after an item is toggled
@@ -279,8 +279,8 @@ class KDE_EXPORT KSubscription : public KDialogBase
* Update the item-states (visible, enabled) when a filter
* criteria changed
*/
- void filterChanged( QListViewItem* item = 0,
- const QString & text = QString::null );
+ void filterChanged( TQListViewItem* item = 0,
+ const TQString & text = TQString::null );
/**
* The amount of items that are visible and enabled
@@ -312,7 +312,7 @@ class KDE_EXPORT KSubscription : public KDialogBase
/**
* Changes the current state of the buttons
*/
- void slotChangeButtonState( QListViewItem* );
+ void slotChangeButtonState( TQListViewItem* );
/**
* Buttons are clicked
@@ -339,7 +339,7 @@ class KDE_EXPORT KSubscription : public KDialogBase
/**
* Filter text changed
*/
- void slotFilterTextChanged( const QString & text );
+ void slotFilterTextChanged( const TQString & text );
signals:
/**
@@ -354,15 +354,15 @@ class KDE_EXPORT KSubscription : public KDialogBase
KAccount* mAcct;
// widgets
- QWidget *page;
- QListView *groupView;
- QListView *subView, *unsubView;
+ TQWidget *page;
+ TQListView *groupView;
+ TQListView *subView, *unsubView;
KLineEdit *filterEdit;
- QCheckBox *noTreeCB, *subCB, *newCB;
- QPushButton *arrowBtn1, *arrowBtn2;
- QIconSet pmRight, pmLeft;
- QGridLayout *listL;
- QLabel *leftLabel, *rightLabel;
+ TQCheckBox *noTreeCB, *subCB, *newCB;
+ TQPushButton *arrowBtn1, *arrowBtn2;
+ TQIconSet pmRight, pmLeft;
+ TQGridLayout *listL;
+ TQLabel *leftLabel, *rightLabel;
// false if all items are loaded
bool mLoading;
@@ -372,7 +372,7 @@ class KDE_EXPORT KSubscription : public KDialogBase
Direction mDirButton2;
// remember last searchtext
- QString mLastText;
+ TQString mLastText;
// remember description column
int mDescrColumn;
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
- * Calls QListViewItem or QCheckListItem
+ * Calls TQListViewItem or QCheckListItem
*/
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
- * Calls QListViewItem or QCheckListItem
+ * Calls TQListViewItem or QCheckListItem
*/
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
- * Calls QListViewItem or QCheckListItem
+ * Calls TQListViewItem or QCheckListItem
*/
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
- * Calls QListViewItem or QCheckListItem
+ * Calls TQListViewItem or QCheckListItem
*/
virtual void setup();